# Resources used
* https://github.com/techchrism/valorant-api-docs
* https://github.com/zayKenyon/VALORANT-rank-yoinker as a reference

# TODO
* Properly name functions that return raw json data
* Implement use_cache parameter for functions that use session fetch method


# Legal
This project is not affiliated with Riot Games or any of its employees and therefore does not reflect the views of said parties.

Riot Games does not endorse or sponsor this project. Riot Games, and all associated properties are trademarks or registered trademarks of Riot Games, Inc.